@@ -16,4 +16,16 @@ impl SourcePath {
         let rel_path = RelativePathBuf::from_path(rel_path).ok()?;
         Some(Self { abs_path, rel_path })
     }
+
+    pub fn pop(&mut self) -> bool {
+        let abs = self.abs_path.pop();
+        let rel = self.rel_path.pop();
+        assert_eq!(abs, rel);
+        abs
+    }
+
+    pub fn push(&mut self, name: &str) {
+        self.abs_path.push(name);
+        self.rel_path.push(name);
+    }
 }
